/*******************************************************************************
*                                                                              *
*                                   Viewmol                                    *
*                                                                              *
*                            F A L L B A C K S . H                             *
*                                                                              *
*                 Copyright (c) Joerg-R. Hill, December 1997                   *
*                                                                              *
********************************************************************************
*
* $Id: fallbacks.h,v 1.2 1998/01/26 00:47:41 jrh Exp jrh $
* $Log: fallbacks.h,v $
* Revision 1.2  1998/01/26 00:47:41  jrh
* Release 2.1
*
* Revision 1.1  1996/12/10  18:45:31  jrh
* Initial revision
*
*/
static String fallbacks[] = {
  "Viewmol.webBrowser:                              netscape %s",
  "Viewmol.Moloch:                                  moloch",
  "Viewmol.Rayshade:                                rayshade",
  "Viewmol.DisplayRLE:                              xv %s",
/* the following three resources are necessary to get
   the Indigo Magic Desktop look-and-feel */
  "Viewmol*sgiMode:                                 True",
  "Viewmol*useSchemes:                              all",
  "Viewmol*SgNuseEnhancedFSB:                       True",
/* end of SGI specfic stuff */
  "Viewmol.geometry:                                500x500+50+50",
  "Viewmol.history.geometry:                        500x250+50+590",
  "Viewmol.spectrum.geometry:                       500x250+50+590",
  "Viewmol.MODiagram.geometry:                      250x500+565+50",
  "Viewmol.model:                                   wire",
  "Viewmol.drawingMode:                             surface",
  "Viewmol.bondType:                                conjugated",
  "Viewmol.sphereResolution:                        10",
  "Viewmol.lineWidth:                               0",
  "Viewmol.simplifyWhileRotating:                   True",
  "Viewmol.interpolation:                           linear",
  "Viewmol.bondLength:                              %7.4f Ang",
  "Viewmol.bondAngle:                               %7.2f deg",
  "Viewmol.torsionAngle:                            %7.2f deg",
  "Viewmol.wavenumbers:                             0:5000",
  "Viewmol.isosurface:                              0.05",
  "Viewmol.densityResolution:                       0.01",
  "Viewmol.reservedColors:                          0",
  "Viewmol*spectrumForm*amplitudeSlider.decimalPoints: 2",
  "Viewmol*spectrumForm*amplitudeSlider.minimum:    -250",
  "Viewmol*spectrumForm*amplitudeSlider.maximum:    250",
  "Viewmol*spectrumForm*scaleSlider.decimalPoints:  2",
  "Viewmol*spectrumForm*scaleSlider.minimum:        50",
  "Viewmol*spectrumForm*scaleSlider.maximum:        150",
  "Viewmol*wavefunctionForm*level.minimum:          1",
  "Viewmol*wavefunctionForm*level.maximum:          100",
  "Viewmol*wavefunctionForm*grid.minimum:           4",
  "Viewmol*wavefunctionForm*grid.maximum:           20",
  "Viewmol*wavefunctionForm*grid.value:             10",
  "Viewmol*MODiagramForm*resolution.minimum:        1",
  "Viewmol*MODiagramForm*resolution.maximum:        1000",
  "Viewmol*MODiagramForm*resolution.decimalPoints:  3",
  "Viewmol.paperSize:                               A4",
  "Viewmol.viewer*font:                             variable",
  "Viewmol.spectrum*font:                           variable",
  "Viewmol.history*font:                            variable",
  "Viewmol.MODiagram*font:                          variable",
  "Viewmol*viewer.canvas.background:                white",
  "Viewmol*viewer.canvas.foreground:                gray75",
  "Viewmol*spectrum.canvas.background:              white",
  "Viewmol*spectrum.canvas.foreground:              black",
  "Viewmol*history.canvas.background:               white",
  "Viewmol*history.canvas.foreground:               blue",
  "Viewmol*MODiagram.canvas.background:             white",
  "Viewmol*MODiagram.canvas.foreground:             black",
  "Viewmol*foreground:                              black",
  "Viewmol.title:                                   Viewmol",
  "Viewmol.by:                                      by",
  "Viewmol.version:                                 Version",
  "Viewmol.history.title:                           Optimization History",
  "Viewmol.spectrum.title:                          Spectrum",
  "Viewmol.spectrum.title1:                         All modes",
  "Viewmol.spectrum.title2:                         IR spectrum",
  "Viewmol.spectrum.title3:                         Raman spectrum",
  "Viewmol.spectrum.title4:                         INS spectrum",
  "Viewmol.MODiagram.title:                         Energy level diagram",
  "Viewmol.hasLZW:                                  False",
  "Viewmol*_popup.wire_model.labelString:           Wire model",
  "Viewmol*_popup.wire_model.mnemonic:              W",
  "Viewmol*_popup.wire_model.accelerator:           Meta<Key>W",
  "Viewmol*_popup.stick_model.labelString:          Stick model",
  "Viewmol*_popup.stick_model.mnemonic:             t",
  "Viewmol*_popup.stick_model.accelerator:          Meta<Key>T",
  "Viewmol*_popup.ball_and_stick_model.labelString: Ball and stick model",
  "Viewmol*_popup.ball_and_stick_model.mnemonic:    a",
  "Viewmol*_popup.ball_and_stick_model.accelerator: Meta<Key>A",
  "Viewmol*_popup.cpk_model.labelString:            CPK model",
  "Viewmol*_popup.cpk_model.mnemonic:               C",
  "Viewmol*_popup.cpk_model.accelerator:            Meta<Key>C",
  "Viewmol*_popup.geometry_menu.labelString:        Geometry ...",
  "Viewmol*clear_all.labelString:                   Clear all",
  "Viewmol*clear_all.accelerator:                   Ctrl<Key>A",
  "Viewmol*clear_all.acceleratorText:               Ctrl+A",
  "Viewmol*clear_last.labelString:                  Clear last",
  "Viewmol*clear_last.accelerator:                  Ctrl<Key>L",
  "Viewmol*clear_last.acceleratorText:              Ctrl+L",
  "Viewmol*_popup.bondType_menu.labelString:        Bond type ...",
  "Viewmol*single.labelString:                      single only",
  "Viewmol*single.accelerator:                      Ctrl<Key>S",
  "Viewmol*single.acceleratorText:                  Ctrl+S",
  "Viewmol*multiple.labelString:                    multiple",
  "Viewmol*multiple.accelerator:                    Ctrl<Key>M",
  "Viewmol*multiple.acceleratorText:                Ctrl+M",
  "Viewmol*conjugated.labelString:                  conjugated",
  "Viewmol*conjugated.accelerator:                  Ctrl<Key>C",
  "Viewmol*conjugated.acceleratorText:              Ctrl+C",
  "Viewmol*_popup.wave_function.labelString:        Wave function ...",
  "Viewmol*_popup.wave_function.mnemonic:           v",
  "Viewmol*_popup.wave_function.accelerator:        Meta<Key>V",
  "Viewmol*_popup.energy_level_diagram.labelString: Energy level diagram",
  "Viewmol*_popup.energy_level_diagram.mnemonic:    E",
  "Viewmol*_popup.energy_level_diagram.accelerator: Meta<Key>E",
  "Viewmol*_popup.optimization_history.labelString: Optimization history",
  "Viewmol*_popup.optimization_history.mnemonic:    O",
  "Viewmol*_popup.optimization_history.accelerator: Meta<Key>O",
  "Viewmol*_popup.show_forces.labelString:          Show forces",
  "Viewmol*_popup.show_forces.mnemonic:             f",
  "Viewmol*_popup.show_forces.accelerator:          Meta<Key>F",
  "Viewmol*_popup.spectrum.labelString:             Spectrum",
  "Viewmol*_popup.spectrum.mnemonic:                S",
  "Viewmol*_popup.spectrum.accelerator:             Meta<Key>S",
  "Viewmol*_popup.show_unit_cell.labelString:       Show unit cell",
  "Viewmol*_popup.show_unit_cell.mnemonic:          n",
  "Viewmol*_popup.show_unit_cell.accelerator:       Meta<Key>N",
  "Viewmol*_popup.show_ellipsoid_of_inertia.labelString: Show ellipsoid of inertia",
  "Viewmol*_popup.show_ellipsoid_of_inertia.mnemonic: i",
  "Viewmol*_popup.show_ellipsoid_of_inertia.accelerator: Meta<Key>I",
  "Viewmol*_popup.drawing_modes.labelString:        Drawing modes ...",
  "Viewmol*_popup.drawing_modes.mnemonic:           m",
  "Viewmol*_popup.drawing_modes.accelerator:        Meta<Key>M",
  "Viewmol*_popup.background_color.labelString:     Background color ...",
  "Viewmol*_popup.background_color.mnemonic:        B",
  "Viewmol*_popup.background_color.accelerator:     Meta<Key>B",
  "Viewmol*_popup.foreground_color.labelString:     Ground color ...",
  "Viewmol*_popup.foreground_color.mnemonic:        G",
  "Viewmol*_popup.foreground_color.accelerator:     Meta<Key>G",
  "Viewmol*_popup.label_atoms.labelString:          Label atoms",
  "Viewmol*_popup.label_atoms.mnemonic:             L",
  "Viewmol*_popup.label_atoms.accelerator:          Meta<Key>L",
  "Viewmol*_popup.annotate.labelString:             Annotate",
  "Viewmol*_popup.annotate.accelerator:             Ctrl<Key>N",
  "Viewmol*_popup.annotate.acceleratorText:         Ctrl+N",
  "Viewmol*_popup.hardcopy.labelString:             Save drawing",
  "Viewmol*_popup.hardcopy.mnemonic:                d",
  "Viewmol*_popup.hardcopy.accelerator:             Meta<Key>D",
  "Viewmol*_popup.raytracing.labelString:           Ray tracing",
  "Viewmol*_popup.raytracing.mnemonic:              R",
  "Viewmol*_popup.raytracing.accelerator:           Meta<Key>R",
  "Viewmol*_popup.manual.labelString:               Help/Manual",
  "Viewmol*_popup.manual.mnemonic:                  H",
  "Viewmol*_popup.manual.accelerator:               Meta<Key>H",
  "Viewmol*_popup.saveMolecule.labelString:         Save molecule",
  "Viewmol*_popup.saveConfiguration.labelString:    Save configuration",
  "Viewmol*_popup.quit.labelString:                 Quit",
  "Viewmol*_popup.quit.mnemonic:                    Q",
  "Viewmol*_popup.quit.accelerator:                 Meta<Key>Q",
  "Viewmol*spectrumForm_popup.title:                Settings for spectrum",
  "Viewmol.spectrum*_popup.settings_spectrum.labelString: Settings for spectrum ...",
  "Viewmol.spectrum*_popup.settings_spectrum.mnemonic: S",
  "Viewmol.spectrum*_popup.settings_spectrum.accelerator: Meta<Key>S",
  "Viewmol.spectrum*_popup.observed_spectrum.labelString: Read observed spectrum ...",
  "Viewmol.spectrum*_popup.observed_spectrum.mnemonic: R",
  "Viewmol.spectrum*_popup.observed_spectrum.accelerator: Meta<Key>R",
  "Viewmol.spectrum*_popup.delete_spectrum.labelString: Delete observed spectrum ...",
  "Viewmol.spectrum*_popup.delete_spectrum.mnemonic: e",
  "Viewmol.spectrum*_popup.delete_spectrum.accelerator: Meta<Key>E",
  "Viewmol.spectrum*_popup.imaginary_wave_numbers.labelString: Imaginary wave numbers ...",
  "Viewmol.spectrum*_popup.zoom_out.labelString:    Zoom out",
  "Viewmol.spectrum*_popup.zoom_out.mnemonic:       Z",
  "Viewmol.spectrum*_popup.zoom_out.accelerator:    Meta<Key>Z",
  "Viewmol.spectrum*_popup.hardcopy.labelString:    Save drawing",
  "Viewmol.spectrum*_popup.hardcopy.mnemonic:       d",
  "Viewmol.spectrum*_popup.hardcopy.accelerator:    Meta<Key>D",
  "Viewmol.spectrum*_popup.foreground_color.labelString: Foreground color ...",
  "Viewmol.spectrum*_popup.foreground_color.mnemonic: F",
  "Viewmol.spectrum*_popup.foreground_color.accelerator: Meta<Key>F",
  "Viewmol.spectrum*_popup.background_color.labelString: Background color ...",
  "Viewmol.spectrum*_popup.background_color.mnemonic: B",
  "Viewmol.spectrum*_popup.background_color.accelerator: Meta<Key>B",
  "Viewmol.spectrum*_popup.quit_spectrum.labelString: Quit spectrum",
  "Viewmol.spectrum*_popup.quit_spectrum.mnemonic:  Q",
  "Viewmol.spectrum*_popup.quit_spectrum.accelerator: Meta<Key>Q",
  "Viewmol*historyForm_popup.title:                 Settings for history",
  "Viewmol.history*_popup.settings_history.labelString: Settings for history ...",
  "Viewmol.history*_popup.settings_history.mnemonic: S",
  "Viewmol.history*_popup.settings_history.accelerator: Meta<Key>S",
  "Viewmol.history*_popup.hardcopy.labelString:     Save drawing",
  "Viewmol.history*_popup.hardcopy.mnemonic:        d",
  "Viewmol.history*_popup.hardcopy.accelerator:     Meta<Key>D",
  "Viewmol.history*_popup.energy_color.labelString: Color for energy...",
  "Viewmol.history*_popup.energy_color.mnemonic:    e",
  "Viewmol.history*_popup.energy_color.accelerator: Meta<Key>E",
  "Viewmol.history*_popup.gradient_color.labelString: Color for gradient...",
  "Viewmol.history*_popup.gradient_color.mnemonic:  g",
  "Viewmol.history*_popup.gradient_color.accelerator: Meta<Key>G",
  "Viewmol.history*_popup.background_color.labelString: Background color ...",
  "Viewmol.history*_popup.background_color.mnemonic: B",
  "Viewmol.history*_popup.background_color.accelerator: Meta<Key>B",
  "Viewmol.history*_popup.quit_history.labelString: Quit optimization history",
  "Viewmol.history*_popup.quit_history.mnemonic:    Q",
  "Viewmol.history*_popup.quit_history.accelerator: Meta<Key>Q",
  "Viewmol.MODiagram*_popup.settings_modiagram.labelString: Settings for energy level diagram ...",
  "Viewmol.MODiagram*_popup.settings_modiagram.mnemonic: S",
  "Viewmol.MODiagram*_popup.settings_modiagram.accelerator: Meta<Key>S",
  "Viewmol.MODiagram*_popup.transition.labelString: Transition",
  "Viewmol.MODiagram*_popup.transition.mnemonic:    T",
  "Viewmol.MODiagram*_popup.transition.accelerator: Meta<Key>T",
  "Viewmol.MODiagram*_popup.zoom_out.labelString:   Zoom out",
  "Viewmol.MODiagram*_popup.zoom_out.mnemonic:      Z",
  "Viewmol.MODiagram*_popup.zoom_out.accelerator:   Meta<Key>Z",
  "Viewmol.MODiagram*_popup.hardcopy.labelString:   Save drawing",
  "Viewmol.MODiagram*_popup.hardcopy.mnemonic:      d",
  "Viewmol.MODiagram*_popup.hardcopy.accelerator:   Meta<Key>D",
  "Viewmol.MODiagram*_popup.energy_levels.labelString: Draw density of states",
  "Viewmol.MODiagram*_popup.energy_levels.mnemonic: e",
  "Viewmol.MODiagram*_popup.energy_levels.accelerator: Meta<Key>E",
  "Viewmol.MODiagram*_popup.foreground_color.labelString: Foreground color ...",
  "Viewmol.MODiagram*_popup.foreground_color.mnemonic: F",
  "Viewmol.MODiagram*_popup.foreground_color.accelerator: Meta<Key>F",
  "Viewmol.MODiagram*_popup.background_color.labelString: Background color ...",
  "Viewmol.MODiagram*_popup.background_color.mnemonic: B",
  "Viewmol.MODiagram*_popup.background_color.accelerator: Meta<Key>B",
  "Viewmol.MODiagram*_popup.quit_modiagram.labelString: Quit energy level diagram",
  "Viewmol.MODiagram*_popup.quit_modiagram.mnemonic: Q",
  "Viewmol.MODiagram*_popup.quit_modiagram.accelerator: Meta<Key>Q",
  "Viewmol*messageForm_popup*exit.labelString:      Exit",
  "Viewmol*messageForm_popup*title:                 Note",
  "Viewmol*basisForm_popup.title:                   Basis functions",
  "Viewmol*basisForm_popup.basisForm.rowcolumn.atomname.labelString: Basis functions of atom %s%d",
  "Viewmol.fileSelectionBox_popup.title:            File selection",
  "Viewmol*fileSelectionBox.dirListLabelString:     Directories",
  "Viewmol*fileSelectionBox.fileListLabelString:    Files",
  "Viewmol*fileSelectionBox.filterLabelString:      Path",
  "Viewmol*fileSelectionBox.applyLabelString:       Filter",
  "Viewmol*fileSelectionBox.okLabelString:          OK",
  "Viewmol*fileSelectionBox.cancelLabelString:      Cancel",
  "Viewmol*fileSelectionBox.selectionLabelString:   Selection",
  "Viewmol*ok.labelString:                          OK",
  "Viewmol*cancel.labelString:                      Cancel",
  "Viewmol*continue.labelString:                    Continue",
  "Viewmol*optimizationForm_popup*title:            Optimization history",
  "Viewmol*optimizationForm*energies.labelString:   Energies",
  "Viewmol*optimizationForm*norms.labelString:      Gradient norm",
  "Viewmol*optimizationForm*scales.labelString:     Scales",
  "Viewmol*spectrumForm*all_modes.labelString:      All modes",
  "Viewmol*spectrumForm*ir_modes.labelString:       IR active modes",
  "Viewmol*spectrumForm*raman_modes.labelString:    Raman active modes",
  "Viewmol*spectrumForm*ins_modes.labelString:      Inelastic neutron scattering",
  "Viewmol*spectrumForm*animate.labelString:        Animate",
  "Viewmol*spectrumForm*draw_arrows.labelString:    Draw arrows",
  "Viewmol*spectrumForm*distort.labelString:        Distort",
  "Viewmol*spectrumForm*line_spectrum.labelString:  Line spectrum",
  "Viewmol*spectrumForm*gaussian_spectrum.labelString: Gaussian spectrum",
  "Viewmol*spectrumForm*setins.labelString:         Set weights for inelastic neutron scattering",
  "Viewmol*spectrumForm*temperature.labelString:    Temperature",
  "Viewmol*spectrumForm*amplitude.labelString:      Amplitude",
  "Viewmol*spectrumForm*scale.labelString:          Scale wave\\nnumbers",
  "Viewmol*wavefunctionForm_popup.title:            Wave function",
  "Viewmol*wavefunctionForm*all_off.labelString:    All off",
  "Viewmol*wavefunctionForm*basis_function.labelString: Basis function",
  "Viewmol*wavefunctionForm*basis_in_mo.labelString: Basis function in MO",
  "Viewmol*wavefunctionForm*molecular_orbital.labelString: Molecular orbital",
  "Viewmol*wavefunctionForm*electron_density.labelString: Electron density",
  "Viewmol*wavefunctionForm*interpolationLabel.labelString: Interpolation",
  "Viewmol*wavefunctionForm*none.labelString:       None",
  "Viewmol*wavefunctionForm*linear.labelString:     Linear",
  "Viewmol*wavefunctionForm*logarithmic.labelString: Logarithmic",
  "Viewmol*wavefunctionForm*levelLabel.labelString: Isosurface",
  "Viewmol*wavefunctionForm*gridLabel.labelString:  Resolution of grid",
  "Viewmol*MODiagramForm_popup.title:               Settings",
  "Viewmol*MODiagramForm*hartrees.labelString:      Hartrees",
  "Viewmol*MODiagramForm*kj_mol.labelString:        kJ/mol",
  "Viewmol*MODiagramForm*ev.labelString:            eV",
  "Viewmol*MODiagramForm*cm.labelString:            cm^-1",
  "Viewmol*MODiagramForm*resolutionlabel.labelString: Resolution",
  "Viewmol*printForm_popup.title:                   Save Drawing",
  "Viewmol*printForm*hpgl.labelString:              HPGL",
  "Viewmol*printForm*postscript.labelString:        PostScript",
  "Viewmol*printForm*raytracer.labelString:         Rayshade",
  "Viewmol*printForm*tiff.labelString:              TIFF",
  "Viewmol*printForm*landscape.labelString:         Landscape",
  "Viewmol*printForm*portrait.labelString:          Portrait",
  "Viewmol*printForm*papersize.labelString:         Paper size",
  "Viewmol*printForm*a5.labelString:                A5",
  "Viewmol*printForm*a4.labelString:                A4",
  "Viewmol*printForm*a3.labelString:                A3",
  "Viewmol*printForm*letter.labelString:            Letter",
  "Viewmol*printForm*legal.labelString:             Legal",
  "Viewmol*printForm*userdefined.labelString:       User defined",
  "Viewmol*printForm*lzw.labelString:               LZW",
  "Viewmol*printForm*mac.labelString:               Macintosh",
  "Viewmol*printForm*none.labelString:              None",
  "Viewmol*printForm*compressionlabel.labelString:  TIFF compression",
  "Viewmol*printForm*widthlabel.labelString:        Paper width in mm",
  "Viewmol*printForm*heightlabel.labelString:       Paper height in mm",
  "Viewmol*printForm*file.labelString:              File",
  "Viewmol*printForm*select.labelString:            Select",
  "Viewmol*drawingModeForm_popup.title:             Drawing Modes",
  "Viewmol*drawingModeForm*dots.labelString:        with dots",
  "Viewmol*drawingModeForm*lines.labelString:       with lines",
  "Viewmol*drawingModeForm*surfaces.labelString:    with surface",
  "Viewmol*drawingModeForm*simplify.labelString:    Lines while rotating",
  "Viewmol*drawingModeForm*onOffLabel.labelString:  Lights on/off",
  "Viewmol*drawingModeForm*molecule.labelString:    Move molecule",
  "Viewmol*drawingModeForm*viewpoint.labelString:   Move view point",
  "Viewmol*drawingModeForm*light0.labelString:      Move light 1",
  "Viewmol*drawingModeForm*light1.labelString:      Move light 2",
  "Viewmol*drawingModeForm*projectionLabel.labelString: Projection",
  "Viewmol*drawingModeForm*orthographic.labelString: Orthographic",
  "Viewmol*drawingModeForm*perspective.labelString: Perspective",
  "Viewmol*drawingModeForm*light0OnOff.labelString: Light 1",
  "Viewmol*drawingModeForm*light1OnOff.labelString: Light 2",
  "Viewmol*drawingModeForm*sphereResolutionLabel.labelString: Resolution of spheres",
  "Viewmol*drawingModeForm*lineWidthLabel.labelString: Line width",
  "Viewmol*colorEditor.title:                       Color Editor",
  "Viewmol*colorEditor*smoothRed.labelString:       Smooth",
  "Viewmol*colorEditor*smoothGreen.labelString:     Smooth",
  "Viewmol*colorEditor*smoothBlue.labelString:      Smooth",
  "viewmol*doRaytracing.labelString:                Start raytracing",
  "viewmol*stopRaytracing.labelString:              Don't start raytracing",
  "Viewmol*saveMoleculeForm_popup*title:            Save molecule",
  "Viewmol*saveMoleculeForm*mol.labelString:        MDL mol-file",
  "Viewmol*saveMoleculeForm*tm.labelString:         Turbomole file",
  "Viewmol.unknownParameter:                        Unknown command line parameter: %s",
  "Viewmol.selectFormat:                            Please select format.",
  "Viewmol.selectCompression:                       Please select compression method.",
  "Viewmol.TIFFSaved:                               Drawing saved to TIFF file %s.",
  "Viewmol.HPGLSaved:                               Drawing saved to HPGL file %s.",
  "Viewmol.PostscriptSaved:                         Drawing saved to Postscript file %s.",
  "Viewmol.RaytracerSaved:                          Drawing saved to Rayshade file %s.",
  "Viewmol.MoleculeSaved:                           Molecule saved to file %s.",
  "Viewmol.ConfigurationSaved:                      Configuration saved to file $HOME/.Xdefaults.",
  "Viewmol.noControlFile:                           There is no control file in the current directory.",
  "Viewmol.unableToOpen:                            Unable to open file %s.",
  "Viewmol.molochFailed:                            Moloch failed.",
  "Viewmol.noMolochOutput:                          Moloch output does not exist.",
  "Viewmol.errorOnLine:                             Error on line %d of %s.",
  "Viewmol.noColors:                                Unable to allocate sufficient number of colors.",
  "Viewmol.noInputFilter:                           No input filter specified in %s.",
  "Viewmol.noDefaultFilter:                         No default input filter found.",
  "Viewmol.noFile:                                  File %s not found.",
  "Viewmol.FileExists:                              File %s already exists.",
  "Viewmol.cannotExecute:                           Cannot execute: %s.",
  "Viewmol.notConverged:                            MOs in %s are not converged.",
  "Viewmol.noBrowser:                               Cannot find Web browser for the manual.\\n%s does not exist. Put a line\\n'Viewmol.webBrowser: <your Web browser>'\\ninto your $HOME/.Xdefaults file.",
  "Viewmol.noManual:                                Manual file %s\\ndoes not exist.",
  "Viewmol.cannotDisplay:                           Unable to display manual.\nWeb browser does not start.",
  "Viewmol.noVisual:                                Unable to find a window suitable for OpenGL drawing.\\nThere might be an installation problem with OpenGL\\nor the X server has not been started with the\\ncorrect extensions.",
  "Viewmol.noRayshade:                              No location for Rayshade specified in resources.",
  "Viewmol.noDisplay:                               No display program for RLE files specified in resources.",
  "Viewmol.unableToWriteFeedback:                   Cannot allocate enough memory to write drawing to file.",
  "Viewmol.wavenumberTitle:                         %s mode, %.6g cm-1",
  "Viewmol.selectAtomTitle:                         Please select atom by clicking on it.",
  "Viewmol.selectINSTitle:                          Click on atom to set INS weight to %f.",
  "Viewmol.basisfunctionTitle:                      Basis function %d: %s%d %s",
  "Viewmol.basisfunctionInMOTitle:                  Basis function %d in MO %d: %s%d %.7f*%s",
  "Viewmol.molecularOrbitalTitle:                   Molecular orbital %d: %s, energy %f Hartree",
  "Viewmol.electronDensityTitle:                    Electron density",
  "Viewmol.isosurfaceLabel:                         isosurface: ",
  "Viewmol.isosurfaceLevel:                         %.3f ",
  "Viewmol.historyTitle:                            Cycle %d Energy %18.10f Hartree, |dE/dxyz| %10.6f",
  "Viewmol.wavenumber:                              Wave numbers (cm**-1)",
  "Viewmol.intensity:                               Intensity (%)",
  "Viewmol.energy:                                  Energy",
  "Viewmol.gradientNorm:                            Gradient norm",
  "Viewmol.animateSave:                             You cannot plot an animated molecule.",
  "Viewmol.noNormalModes:                           Normal modes have not been read in.",
  "Viewmol.fGaussian:                               I have found f functions in a Gaussian output.\\nI do not know how to handle them.",
  "Viewmol.GaussianProblem:                         The Gaussian output contains %c functions.\\nThis combination is currently not supported.",
  "Viewmol.unknownResource:                         The value %s is not allowed for\\nthe resource %s.",
  "Viewmol.unsupportedVersion:                      Files of version %s are not supported.",
  "Viewmol.wrongFiletype:                           File %s is of wrong file type.",
  "Viewmol.wrongReference:                          File referenced in %s as 'type=car' is of wrong file type.",
  "Viewmol.unknownErrorMessage:                     Input filter sent unknown error message:\\n%s.",
  "Viewmol.noCoordinates:                           Cannot find coordinates in file %s.",
  "Viewmol.noEnergy:                                Cannot find energy in file %s.",
  "Viewmol.noMOselected:                            There is no MO selected. Please select a MO\\nin the energy level diagram, then try again.",
  NULL
};
